# tweet-py
Python package which to access the Tweet data without API

## Usage

Download it by clicking the green download button here on Github. You only need to parse argument specific Twitter keyword.
```python
>>> from tweetpy.tweet import Tweet
>>> tweet = Tweet(1567531687130632199)
```

<!--
python  -m venv venv
source venv/bin/activate
pip install wheel setuptools twine
python setup.py sdist bdist_wheel
python -m twine upload dist/*
-->
